[pve-devel] [PATCH pve-manager 13/18] vzdump: rename 'sendmail' sub to 'send_notification'

Lukas Wagner l.wagner at proxmox.com
Mon Mar 27 17:18:52 CEST 2023


Signed-off-by: Lukas Wagner <l.wagner at proxmox.com>
---
 PVE/API2/VZDump.pm |  2 +-
 PVE/VZDump.pm      | 10 ++++------
 test/mail_test.pl  |  6 +++---
 3 files changed, 8 insertions(+), 10 deletions(-)

diff --git a/PVE/API2/VZDump.pm b/PVE/API2/VZDump.pm
index 8e873c05..83772e73 100644
--- a/PVE/API2/VZDump.pm
+++ b/PVE/API2/VZDump.pm
@@ -126,7 +126,7 @@ __PACKAGE__->register_method ({
 		$vzdump->getlock($upid); # only one process allowed
 	    };
 	    if (my $err = $@) {
-		$vzdump->sendmail([], 0, $err);
+		$vzdump->send_notification([], 0, $err);
 		exit(-1);
 	    }
 
diff --git a/test/mail_test.pl b/test/mail_test.pl
index c77c1aae..2dfbf067 100755
--- a/test/mail_test.pl
+++ b/test/mail_test.pl
@@ -73,19 +73,19 @@ sub prepare_test {
 
 {
     prepare_test($TEST_FILE_WRONG_PATH);
-    PVE::VZDump::sendmail($SELF, $tasklist, 0, undef, undef, undef);
+    PVE::VZDump::send_notification($SELF, $tasklist, 0, undef, undef, undef);
     like($result_text, $NO_LOGFILE, "Missing logfile is detected");
 }
 {
     prepare_test($TEST_FILE_PATH);
     prepare_mail_with_status();
-    PVE::VZDump::sendmail($SELF, $tasklist, 0, undef, undef, undef);
+    PVE::VZDump::send_notification($SELF, $tasklist, 0, undef, undef, undef);
     unlike($result_text, $STATUS, "Status are not in text part of mails");
 }
 {
     prepare_test($TEST_FILE_PATH);
     prepare_long_mail();
-    PVE::VZDump::sendmail($SELF, $tasklist, 0, undef, undef, undef);
+    PVE::VZDump::send_notification($SELF, $tasklist, 0, undef, undef, undef);
     like($result_text, $LOG_TOO_LONG, "Text part of mails gets shortened");
 }
 unlink $TEST_FILE_PATH;
diff --git a/PVE/VZDump.pm b/PVE/VZDump.pm
index c0971220..f1a0a5bd 100644
--- a/PVE/VZDump.pm
+++ b/PVE/VZDump.pm
@@ -302,15 +302,13 @@ sub read_vzdump_defaults {
 }
 
 use constant MAX_MAIL_SIZE => 1024*1024;
-sub sendmail {
+sub send_notification {
     my ($self, $tasklist, $totaltime, $err, $detail_pre, $detail_post) = @_;
 
     my $opts = $self->{opts};
 
     my $mailto = $opts->{mailto};
 
-    # return if !($mailto && scalar(@$mailto));
-
     my $cmdline = $self->{cmdline};
 
     my $ecount = 0;
@@ -563,7 +561,7 @@ sub new {
     }
 
     if ($errors) {
-	eval { $self->sendmail([], 0, $errors); };
+	eval { $self->send_notification([], 0, $errors); };
 	debugmsg ('err', $@) if $@;
 	die "$errors\n";
     }
@@ -1253,11 +1251,11 @@ sub exec_backup {
     my $totaltime = time() - $starttime;
 
     eval {
 	# otherwise $self->sendmail() will interpret it as multiple problems
 	my $chomped_err = $err;
 	chomp($chomped_err) if $chomped_err;
 
-	$self->sendmail(
+	$self->send_notification(
 	    $tasklist,
 	    $totaltime,
 	    $chomped_err,
@@ -1253,11 +1251,11 @@ sub exec_backup {
 
     eval {
-	# otherwise $self->sendmail() will interpret it as multiple problems
+	# otherwise $self->send_notification() will interpret it as multiple problems
 	my $chomped_err = $err;
 	chomp($chomped_err) if $chomped_err;
-- 
2.30.2






More information about the pve-devel mailing list